==> huaweicloudsdkdgc-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/execute_script_request.py <==
# coding: utf-8

import re
import six





class ExecuteScriptRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'script_name': 'str',
        'body': 'ExecuteScriptReq'
    }

    attribute_map = {
        'script_name': 'script_name',
        'body': 'body'
    }

    def __init__(self, script_name=None, body=None):
        """ExecuteScriptRequest - a model defined in huaweicloud sdk"""
        
        

        self._script_name = None
        self._body = None
        self.discriminator = None

        self.script_name = script_name
        if body is not None:
            self.body = body

    @property
    def script_name(self):
        """Gets the script_name of this ExecuteScriptRequest.


        :return: The script_name of this ExecuteScriptRequest.
        :rtype: str
        """
        return self._script_name

    @script_name.setter
    def script_name(self, script_name):
        """Sets the script_name of this ExecuteScriptRequest.


        :param script_name: The script_name of this ExecuteScriptRequest.
        :type: str
        """
        self._script_name = script_name

    @property
    def body(self):
        """Gets the body of this ExecuteScriptRequest.


        :return: The body of this ExecuteScriptRequest.
        :rtype: ExecuteScriptReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ExecuteScriptRequest.


        :param body: The body of this ExecuteScriptRequest.
        :type: ExecuteScriptReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteScriptRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdgc-3.0.53-py2.py3-none-any.whl: huaweicloudsdkdgc/v1/model/execute_script_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExecuteScriptRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'script_name': 'str',
        'body': 'ExecuteScriptReq'
    }

    attribute_map = {
        'script_name': 'script_name',
        'body': 'body'
    }

    def __init__(self, script_name=None, body=None):
        """ExecuteScriptRequest - a model defined in huaweicloud sdk"""
        
        

        self._script_name = None
        self._body = None
        self.discriminator = None

        self.script_name = script_name
        if body is not None:
            self.body = body

    @property
    def script_name(self):
        """Gets the script_name of this ExecuteScriptRequest.


        :return: The script_name of this ExecuteScriptRequest.
        :rtype: str
        """
        return self._script_name

    @script_name.setter
    def script_name(self, script_name):
        """Sets the script_name of this ExecuteScriptRequest.


        :param script_name: The script_name of this ExecuteScriptRequest.
        :type: str
        """
        self._script_name = script_name

    @property
    def body(self):
        """Gets the body of this ExecuteScriptRequest.


        :return: The body of this ExecuteScriptRequest.
        :rtype: ExecuteScriptReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ExecuteScriptRequest.


        :param body: The body of this ExecuteScriptRequest.
        :type: ExecuteScriptReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecuteScriptRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
